@@ -120,7 +120,8 @@ class TestDeployCommand(unittest.TestCase):
                     None,
                     fake_tags,
                     True,
-                    True
+                    True,
+                    False
                 )
 
                 self.deploy_command.parse_key_value_arg.assert_has_calls([
@@ -207,7 +208,8 @@ class TestDeployCommand(unittest.TestCase):
                 s3UploaderObject,
                 [{"Key": "tagkey1", "Value": "tagvalue1"}],
                 True,
-                True
+                True,
+                False
             )
 
             s3UploaderMock.assert_called_once_with(mock.ANY,
